@@ -12,6 +12,7 @@ from logging.handlers import RotatingFileHandler
 
 import sys
 from dataclasses import dataclass
+from typing import Optional
 
 
 @dataclass
@@ -33,7 +34,7 @@ class CustomFormatter(logging.Formatter):
         return logging.Formatter.format(self, record)
 
 
-def init_logs(settings: LogsConfig = None) -> None:
+def init_logs(settings: Optional[LogsConfig] = None, logging_formatter: Optional[logging.Formatter] = None) -> None:
     if settings is None:
         settings = LogsConfig()
 
@@ -47,5 +48,6 @@ def init_logs(settings: LogsConfig = None) -> None:
         ch = RotatingFileHandler(settings.filename, maxBytes=max_file_bytes, backupCount=settings.max_files_amount)
     ch.setLevel(logging.getLevelName(settings.level))
 
-    ch.setFormatter(CustomFormatter(datefmt='%Y-%m-%d %H:%M:%S'))
+    if logging_formatter is None:
+        ch.setFormatter(CustomFormatter(datefmt='%Y-%m-%d %H:%M:%S'))
     root.addHandler(ch)
